#define AUTOOPTS_INTERNAL
#include "compat/compat.h"
#define LOCAL static
#include "autoopts/options.h"
#include "autoopts/usage-txt.h"
#include "genshell.h"
#include "autoopts.h"
#include "proto.h"
#include "autoopts.c"
#include "boolean.c"
#include "configfile.c"
#include "cook.c"
#include "enumeration.c"
#include "environment.c"
#include "genshell.c"
#include "load.c"
#include "makeshell.c"
#include "nested.c"
#include "numeric.c"
#include "pgusage.c"
#include "putshell.c"
#include "restore.c"
#include "save.c"
#include "sort.c"
#include "stack.c"
#include "streqvcmp.c"
#include "text_mmap.c"
#include "tokenize.c"
#include "usage.c"
#include "version.c"
